@@ -1,9 +1,6 @@
 from django.db import models
 from edc_action_item.models.action_model_mixin import ActionModelMixin
-from edc_identifier.model_mixins import (
-    NonUniqueSubjectIdentifierFieldMixin,
-    TrackingModelMixin,
-)
+from edc_identifier.model_mixins import NonUniqueSubjectIdentifierFieldMixin
 from edc_model import models as edc_models
 from edc_sites.models import SiteModelMixin
 
@@ -16,7 +13,6 @@ class Ltfu(
     LtfuModelMixin,
     SiteModelMixin,
     ActionModelMixin,
-    TrackingModelMixin,
     edc_models.BaseUuidModel,
 ):
 
