@@ -1,5 +1,4 @@
 from edc_action_item.models import ActionModelMixin
-from edc_identifier.model_mixins import TrackingModelMixin
 from edc_model.models import BaseUuidModel
 from edc_offstudy.constants import END_OF_STUDY_ACTION
 from edc_visit_schedule.model_mixins import OffScheduleModelMixin
@@ -8,7 +7,6 @@ from edc_visit_schedule.model_mixins import OffScheduleModelMixin
 class OffSchedule(
     OffScheduleModelMixin,
     ActionModelMixin,
-    TrackingModelMixin,
     BaseUuidModel,
 ):
 
